{% extends "base.html" %}
{% load l10n %}
{% block js %} 
{% comment %}
<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>
{% endcomment %}
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = "//connect.facebook.net/eu_ES/all.js#xfbml=1";
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>

<script src="http://platform.twitter.com/widgets.js" type="text/javascript"></script>
{% endblock %}
{% block admin %}
{% if user.is_staff %}
<a href="{% url admin:news_article_change obj.id|unlocalize %}">Admin: {{obj.title}}</a>
{% endif %}
{% endblock %}

{% if obj %}{% block title%}{{obj.title}} {% endblock %}{%endif%} 
{% block content%}

<div id="fb-root"></div>

<div class="news">
<h1>{{obj.title}}</h1>

<p class="data">{{obj.published}} &nbsp;&brvbar;&nbsp; {{obj.tags}}</p>
<div class="summary">{{obj.summary|safe}}</div>
{{obj.body|safe}}


</div>
<div id="partekatu">
<a href="https://twitter.com/share" class="twitter-share-button" data-lang="eu" data-via="ahotsak">Tweet</a>
<div class="fb-like" data-send="false" data-width="450" data-show-faces="true"></div>
</div>

{% include "comments/comment_block.html" %}
{% endblock %}

{%block menu%}
{% if obj.image%}
<img src="{{ obj.image.get_menusize_url }}" alt="" />
{% endif %}

<div id="harpidetzak">
</div>
{%endblock%} 


